# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgver 2.13
%define pkgname ovn23.06

# If libcap-ng isn't available and there is no need for running OVS
# as regular user, specify the '--without libcapng'
%bcond_without libcapng

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

# We would see rpmlinit error - E: hardcoded-library-path in '% {_prefix}/lib'.
# But there is no solution to fix this. Using {_lib} macro will solve the
# rpmlink error, but will install the files in /usr/lib64/.
# OVN pacemaker ocf script file is copied in /usr/lib/ocf/resource.d/ovn/
# and we are not sure if pacemaker looks into this path to find the
# OVN resource agent script.
%global ovnlibdir %{_prefix}/lib

Name: %{pkgname}
Summary: Open Virtual Network support
Group: System Environment/Daemons
URL: http://www.ovn.org/
Version: 23.06.0
Release: 56%{?commit0:.%{date}git%{shortcommit0}}%{?dist}
Provides: openvswitch%{pkgver}-ovn-common = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-common < 2.11.0-1

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
License: ASL 2.0 and LGPLv2+ and SISSL

%define ovncommit 638de44d53a3f7c8387ae980fd3e99ce1c9e47d9

# Always pull an upstream release, since this is what we rebase to.
Source: https://github.com/ovn-org/ovn/archive/%{ovncommit}.tar.gz#/ovn-%{version}.tar.gz

%define ovscommit 0187eadfce4505d502e57c0e688b830f0a1ec728
%define ovsshortcommit 0187ead

Source10: https://github.com/openvswitch/ovs/archive/%{ovscommit}.tar.gz#/openvswitch-%{ovsshortcommit}.tar.gz
%define ovsdir ovs-%{ovscommit}

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.1.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Source500: configlib.sh
Source501: gen_config_group.sh
Source502: set_config.sh

# Important: source503 is used as the actual copy file
# @TODO: this causes a warning - fix it?
Source504: arm64-armv8a-linuxapp-gcc-config
Source505: ppc_64-power8-linuxapp-gcc-config
Source506: x86_64-native-linuxapp-gcc-config

Patch:     %{pkgname}.patch

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel

# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} == 8 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
BuildRequires: tcpdump

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

Requires: hostname openssl iproute module-init-tools

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

# to skip running checks, pass --without check
%bcond_without check

%description
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package central
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-central = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-central < 2.11.0-1

%description central
OVN DB servers and ovn-northd running on a central node.

%package host
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-host = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-host < 2.11.0-1

%description host
OVN controller running on each host.

%package vtep
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Provides: openvswitch%{pkgver}-ovn-vtep = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-vtep < 2.11.0-1

%description vtep
OVN vtep controller

%prep
%autosetup -n ovn-%{ovncommit} -a 10 -p 1

%build
%if 0%{?commit0:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
%endif
./boot.sh

# OVN source code is now separate.
# Build openvswitch first.
# XXX Current openvswitch2.13 doesn't
# use "2.13.0" for version. It's a commit hash
pushd %{ovsdir}
./boot.sh
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}
popd

# Build OVN.
# XXX OVS version needs to be updated when ovs2.13 is updated.
%configure \
        --with-ovs-source=$PWD/%{ovsdir} \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}

%install
%make_install
install -p -D -m 0644 \
        rhel/usr_share_ovn_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ovn

for service in ovn-controller ovn-controller-vtep ovn-northd; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/ovn

install -d $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

install -d -m 0755 $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn
ln -s %{_datadir}/ovn/scripts/ovndb-servers.ocf \
      $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers

install -p -D -m 0644 rhel/etc_logrotate.d_ovn \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/ovn

# remove unneeded files.
rm -f $RPM_BUILD_ROOT%{_bindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_bindir}/vtep-ctl
rm -f $RPM_BUILD_ROOT%{_sbindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/vtep*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/vtep*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/python
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovs*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/bugtool-plugins
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/*.pc
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/openvswitch
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovn-bugtool*
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-overlay-driver \
        $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-underlay-driver

%check
%if %{with check}
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if ! make check TESTSUITEFLAGS='%{_smp_mflags}'; then
        cat tests/testsuite.log
        if ! make check TESTSUITEFLAGS='--recheck'; then
            cat tests/testsuite.log
            # Presently a test case - "2796: ovn -- ovn-controller incremental processing"
            # is failing on aarch64 arch. Let's not exit for this arch
            # until we figure out why it is failing.
            # Test case 93: ovn.at:12105       ovn -- ACLs on Port Groups is failing
            # repeatedly on s390x. This needs to be investigated.
            %ifnarch aarch64
            %ifnarch ppc64le
            %ifnarch s390x
                exit 1
            %endif
            %endif
            %endif
        fi
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre central
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-northd.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-central > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-northd service is running which means old openvswitch-ovn-central
        # is already installed and it will be cleaned up. So start ovn-northd
        # service when posttrans central is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-northd
    fi
fi

%pre host
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-host > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller service is running which means old
        # openvswitch-ovn-host is installed and it will be cleaned up. So
        # start ovn-controller service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller
    fi
fi

%pre vtep
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller-vtep.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-vtep > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller-vtep service is running which means old
        # openvswitch-ovn-vtep is installed and it will be cleaned up. So
        # start ovn-controller-vtep service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
    fi
fi

%preun central
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-northd.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%preun host
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%preun vtep
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller-vtep.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%post
%if %{with libcapng}
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVN_USER_ID=:OVN_USER_ID=:' %{_sysconfdir}/sysconfig/ovn
    sed -i 's:\(.*su\).*:\1 openvswitch openvswitch:' %{_sysconfdir}/logrotate.d/ovn
fi
%endif

%post central
%if 0%{?systemd_post:1}
    %systemd_post ovn-northd.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post host
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post vtep
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller-vtep.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun

%postun central
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-northd.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
    # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%postun host
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%postun vtep
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller-vtep.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%posttrans central
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-northd ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-northd
        /bin/systemctl start ovn-northd.service >/dev/null 2>&1 || :
    fi
fi


%posttrans host
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller
        /bin/systemctl start ovn-controller.service >/dev/null 2>&1 || :
    fi
fi

%posttrans vtep
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller-vtep ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
        /bin/systemctl start ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
fi

%files
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_bindir}/ovn_detrace.py
%{_bindir}/ovn-appctl
%{_bindir}/ovn-ic-nbctl
%{_bindir}/ovn-ic-sbctl
%dir %{_datadir}/ovn/
%dir %{_datadir}/ovn/scripts/
%{_datadir}/ovn/scripts/ovn-ctl
%{_datadir}/ovn/scripts/ovn-lib
%{_datadir}/ovn/scripts/ovndb-servers.ocf
%{_mandir}/man8/ovn-ctl.8*
%{_mandir}/man8/ovn-appctl.8*
%{_mandir}/man8/ovn-nbctl.8*
%{_mandir}/man8/ovn-ic-nbctl.8*
%{_mandir}/man8/ovn-trace.8*
%{_mandir}/man1/ovn-detrace.1*
%{_mandir}/man7/ovn-architecture.7*
%{_mandir}/man8/ovn-sbctl.8*
%{_mandir}/man8/ovn-ic-sbctl.8*
%{_mandir}/man5/ovn-nb.5*
%{_mandir}/man5/ovn-ic-nb.5*
%{_mandir}/man5/ovn-sb.5*
%{_mandir}/man5/ovn-ic-sb.5*
%dir %{ovnlibdir}/ocf/resource.d/ovn/
%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/logrotate.d/ovn
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/ovn

%files central
%{_bindir}/ovn-northd
%{_bindir}/ovn-ic
%{_mandir}/man8/ovn-northd.8*
%{_mandir}/man8/ovn-ic.8*
%{_datadir}/ovn/ovn-nb.ovsschema
%{_datadir}/ovn/ovn-ic-nb.ovsschema
%{_datadir}/ovn/ovn-sb.ovsschema
%{_datadir}/ovn/ovn-ic-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml

%files host
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8*
%{_unitdir}/ovn-controller.service
%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

%files vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8*
%{_unitdir}/ovn-controller-vtep.service

%changelog
* Wed Aug 09 2023 Mohammad Heib <mheib@redhat.com> - 23.06.0-56
- binding: handle ovs ofport update
[Upstream: add62b6779898299c4fc05504f34e728f423f68f]

* Fri Aug 04 2023 Ales Musil <amusil@redhat.com> - 23.06.0-55
- system-tests: Wait for all interfaces to have IPv6
[Upstream: fcce66648bda465356fa7c54d05501c3584dc66f]

* Fri Aug 04 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-54
- tests: fixed "CT flush load balancer backends"
[Upstream: 5e765dce3bafc29cd0dbede1b557daf6dd038e28]

* Fri Aug 04 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-53
- tests: fixed multiple ovn-ic unit tests
[Upstream: 5df48df362780ab101a82d500164549a555581b2]

* Fri Aug 04 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-52
- tests: fixed "Logical flows with Chassis_Template_Var reference"
[Upstream: 8da7fd0065502039c4cf5eef9cec857fd7a2a4d4]

* Thu Jul 27 2023 Ales Musil <amusil@redhat.com> - 23.06.0-51
- controller: Migrate from ct zone UUID name to component name (#2224199)
[Upstream: 3581c2887bffb0829e55879c32dd6219e45cdb97]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-50
- tests: fixed "ARP replies for SNAT external ips"
[Upstream: 1f0e021071a8a91b120e74faca99cfcc538ed45a]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-49
- tests: fixed "ECMP IPv6 symmetric reply"
[Upstream: 2551825c9c03bc9128a8b835be564bf83bcfe867]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-48
- tests: increased bfd-mult to 15
[Upstream: f76aebe25bd1014695c1a6a07fa3c5b90c451628]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-47
- tests: fixed another flake in "send gratuitous ARP for NAT rules on HA distributed router"
[Upstream: ea0bf152d24705aeff8e6b2325e76d0344bbd9d1]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-46
- ovn-controller: remove un-necessary "trying to release" warnings (#2222252)
[Upstream: 79635e4deff1ae853873a0231545aa9ac4923819]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-45
- ovn-controller: avoid monitoring wrong chassis
[Upstream: 8c8c18835dfa43eb6be7c6235fa93bb92082de4f]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-44
- tests: run system tests also with monitor-all=true
[Upstream: 789cf47c2818ecc8a6d3062a3ffc89c01913dfd3]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-43
- tests: fixed "Tiered ACLs"
[Upstream: 0cbd64b5b112d85098ea7a4aad3a8c35f5da7092]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-42
- tests: fixed "basic connectivity with multiple requested-chassis"
[Upstream: 243e23506ee167f051b6184f5ba2400115d6607f]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-41
- tests: fixed flaky "4 HV, 3 LS, 2 LR, packet test with HA distributed router gateway port"
[Upstream: c647fed8be75c39aded928102b47e1140381b2fa]

* Tue Jul 25 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-40
- tests: fixed "Mirror - remote" and "Mirror - local"
[Upstream: e92b0abab9c19173fc094b50b26dc87fa047fc53]

* Wed Jul 19 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-39
- binding: fixed ovn-installed not properly removed (recomputes)
[Upstream: d2aaf1b131fa593dbf44c93d0136a900517b30e4]

* Wed Jul 19 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-38
- binding: fixed ovn-installed not properly removed (migration)
[Upstream: 610d9fdf5aa5f7cd4752dc8beb2f42ef17523333]

* Wed Jul 19 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-37
- tests: fixed typos in macro logs
[Upstream: 544504aa3318abbacad558c890b63a0bf0ee3481]

* Mon Jul 17 2023 Dumitru Ceara <dceara@redhat.com> - 23.06.0-36
- ci: ovn-kubernetes: Figure out dependencies dynamically.
[Upstream: 139be79b07a850f9b458da7a0a6a752480d01f5d]

* Mon Jul 17 2023 Ales Musil <amusil@redhat.com> - 23.06.0-35
- ofctrl-seqno: Do not truncate the last acked value (#2074019)
[Upstream: fa454b046be90c9753a431b9e52b095655ec0603]

* Mon Jul 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-34
- binding: fixed qos when no iface
[Upstream: c0158f3a17810673df2c120c01d510ba8d2f39df]

* Mon Jul 17 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-33
- qos: fix potential double deletion of ovs idl row (#2213219)
[Upstream: 709d374b917e039d3668b4e6ab280d4c5cd3c4bd]

* Fri Jul 14 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-32
- tests: fixed userspace-system tests not properly cleaned up
[Upstream: d95d150758e1516a4ab34c15cd9428d214759580]

* Fri Jul 14 2023 Dumitru Ceara <dceara@redhat.com> - 23.06.0-31
- pinctrl: Cap the max size of a prefix delegation DUID value.
[Upstream: d62049f2a87239406f1852c9489baa8a86696971]

* Thu Jul 13 2023 Dumitru Ceara <dceara@redhat.com> - 23.06.0-30
- tests: Remove accidental debug echo.
[Upstream: 4d4233e00a3a32bcd02c3667f95844fae544e49d]

* Wed Jul 12 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-29
- binding: fixed port claims as additional_chassis
[Upstream: 2f5199cbfdd283f612558ae37c5bf1d4e536be2a]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-28
- tests: fixed "ovn-controller port security OF flows"
[Upstream: e7969a47f82a0022e02e503a4d38b44b01333dc8]

* Wed Jul 05 2023 Ales Musil <amusil@redhat.com> - 23.06.0-27
- system-tests: Do not hardcode DP key for the flows
[Upstream: 3a2dfd5b0e447254c62f32fabc7be43ca43bdb6e]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-26
- tests: fixed "MAC binding aging" and "IGMP external querier"
[Upstream: a27ed93f9de6a344810301cffb7d581500036250]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-25
- tests: fixed "ACL Reject ping pong"
[Upstream: 2b687771f8b029e4c950800f407047893f4b90eb]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-24
- tests: fixed "nb_cfg timestamp"
[Upstream: 6ac3b49e7a79573a37afaace3815c5b47fb667f9]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-23
- tests: fixed "send gratuitous arp for nat ips in localnet"
[Upstream: 5547749dc3fafe0071eea1c65a42bf1af9a65e70]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-22
- tests: fixed "check meters update"
[Upstream: a1e0cd314b681f5dc5555b62cbe1d3a60c42c6d5]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-21
- tests: fixed "Encaps tunnel cleanup does not interfere with multiple controller on the same host"
[Upstream: 29025f6ce4623f2fa7253475c027ab136146cab8]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-20
- tests: fixed "IPv6 periodic RA"
[Upstream: 9f3592ac6ea21429cb4ba0c717c15ef16e7a6817]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-19
- tests: decreased failure rate of "tug-of-war between two chassis for the same port"
[Upstream: 589f8d78b6539da7dad5138303f853592daa3851]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-18
- tests: fixed "Load balancer health checks - IPv4 and IPv6"
[Upstream: 96b748d4e2035d7c465815c127497465aaf5fd90]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-17
- tests: fixed "send gratuitous ARP for NAT rules on HA distributed router"
[Upstream: 2b431529b22fe6d8148f16613ce422c106dfc008]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-16
- tests: fixed "dhcpv6 : 1 HV, 2 LS, 5 LSPs" and "external logical port"
[Upstream: 695366c3bfe5a7ffd1167ad5956de0de8e71c936]

* Wed Jul 05 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-15
- tests: fixed "policy-based routing" and "route tables IPv6 -- overlapping subnets"
[Upstream: e863aec96e4ff57f66f0ebc281da1608ec4b3d64]

* Fri Jun 30 2023 Han Zhou <hzhou@ovn.org> - 23.06.0-14
- mirror.c: Fix ovn-controller crash when mirror port is deleted from ovs.
[Upstream: e06f75bb876993e8e33f5ddb0066a0b984b1e296]

* Fri Jun 09 2023 Igor Zhukov <ivzhukov@sbercloud.ru> - 23.06.0-13
- call ovsrcu_exit() before exit in ovn-northd and ovn-controller to make valgrind happy
[Upstream: d1595e5b3420c0731a100d088e2b842df15e95f4]

* Thu Jun 08 2023 Dumitru Ceara <dceara@redhat.com> - 23.06.0-12
- controller: Turn OFTABLE_OUTPUT_INIT into an alias.
[Upstream: 1b8c7f6684c6feab3d223a32459752dae94aea98]

* Thu Jun 08 2023 Ales Musil <amusil@redhat.com> - 23.06.0-11
- northd: Add logical flow to skip GARP with LLA (#2211240)
[Upstream: 4af89ed6564ca18dd4ff73158560c36bfa38e49f]

* Thu Jun 08 2023 Vladislav Odintsov <odivlad@gmail.com> - 23.06.0-10
- northd: match only on supported protocols to handle_svc_check (#1913162)
[Upstream: 8dc2bc3a4f5dab7b00ed7a91af94a571f4708b2f]

* Thu Jun 08 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-9
- tests: Fixed "nested containers" test
[Upstream: 98edd6ea4fbc8908bb64c7c8eaeadb5ffd89a359]

* Thu Jun 08 2023 Xavier Simonart <xsimonar@redhat.com> - 23.06.0-8
- tests: fix flaky Multiple OVS interfaces bound to same logical ports
[Upstream: eaf443375c5312bcd01676baf20ee9852c15892d]

* Thu Jun 08 2023 Ales Musil <amusil@redhat.com> - 23.06.0-7
- system-tests: Prevent flakiness in ovn mirroring
[Upstream: 2a6aaba0746df3331a891fd92de3b85112aab642]

* Thu Jun 08 2023 Ales Musil <amusil@redhat.com> - 23.06.0-6
- system-tests: Prevent flakiness in Tiered ACLS
[Upstream: 2285a84c4f19cdc19663dc4960c1a9590688de1b]

* Thu Jun 08 2023 Ales Musil <amusil@redhat.com> - 23.06.0-5
- northd: Fix address set incremental processing (#2196885)
[Upstream: 1eb8d03fe1520468e5ab4bace07cd42407095f07]

* Fri Jun 02 2023 Mark Michelson <mmichels@redhat.com> - 23.06.0-4
- Prepare for 23.06.1.
[Upstream: 80364da1f842e64c13dc4403dfbc3192b27a6819]

